@@ -3,6 +3,6 @@ from wsblib.request import RequestData
 
 from .mathiz import Mathiz
 
-request = RequestData(HTTPData(), (), {})
+request = RequestData(HTTPData(), ())
 
-__version__ = '0.2.1'
+__version__ = '0.3.1'
